==> debezium-connector-cassandra-core-1.9.4.Final-test-sources.jar: io/debezium/connector/cassandra/TestingKafkaRecordEmitter.java <==
/*
 * Copyright Debezium Authors.
 *
 * Licensed under the Apache Software License version 2.0, available at http://www.apache.org/licenses/LICENSE-2.0
 */
package io.debezium.connector.cassandra;

import java.time.Duration;
import java.util.ArrayList;
import java.util.List;
import java.util.Set;

import org.apache.kafka.clients.producer.KafkaProducer;
import org.apache.kafka.clients.producer.ProducerRecord;
import org.apache.kafka.connect.storage.Converter;

public class TestingKafkaRecordEmitter extends KafkaRecordEmitter {

    public List<ProducerRecord<byte[], byte[]>> records = new ArrayList<>();

    public TestingKafkaRecordEmitter(String kafkaTopicPrefix, String heartbeatPrefix, KafkaProducer kafkaProducer,
                                     OffsetWriter offsetWriter, Duration offsetFlushIntervalMs, long maxOffsetFlushSize,
                                     Converter keyConverter, Converter valueConverter, Set<String> erroneousCommitLogs,
                                     CommitLogTransfer commitLogTransfer) {
        super(kafkaTopicPrefix, heartbeatPrefix, kafkaProducer, offsetWriter, offsetFlushIntervalMs, maxOffsetFlushSize, keyConverter, valueConverter,
                erroneousCommitLogs, commitLogTransfer);
    }

    @Override
    public void emit(Record record) {
        toProducerRecord(record);
    }

    @Override
    protected ProducerRecord<byte[], byte[]> toProducerRecord(Record record) {
        ProducerRecord<byte[], byte[]> producerRecord = super.toProducerRecord(record);
        records.add(producerRecord);
        return producerRecord;
    }
}

==> debezium-connector-cassandra-core-2.0.0.Final-test-sources.jar: io/debezium/connector/cassandra/TestingKafkaRecordEmitter.java <==
/*
 * Copyright Debezium Authors.
 *
 * Licensed under the Apache Software License version 2.0, available at http://www.apache.org/licenses/LICENSE-2.0
 */
package io.debezium.connector.cassandra;

import java.time.Duration;
import java.util.ArrayList;
import java.util.List;
import java.util.Set;

import org.apache.kafka.clients.producer.KafkaProducer;
import org.apache.kafka.clients.producer.ProducerRecord;
import org.apache.kafka.connect.storage.Converter;

public class TestingKafkaRecordEmitter extends KafkaRecordEmitter {

    public List<ProducerRecord<byte[], byte[]>> records = new ArrayList<>();

    public TestingKafkaRecordEmitter(CassandraConnectorConfig connectorConfig, KafkaProducer kafkaProducer,
                                     OffsetWriter offsetWriter, Duration offsetFlushIntervalMs, long maxOffsetFlushSize,
                                     Converter keyConverter, Converter valueConverter, Set<String> erroneousCommitLogs,
                                     CommitLogTransfer commitLogTransfer) {
        super(connectorConfig, kafkaProducer, offsetWriter, offsetFlushIntervalMs, maxOffsetFlushSize, keyConverter, valueConverter,
                erroneousCommitLogs, commitLogTransfer);
    }

    @Override
    public void emit(Record record) {
        toProducerRecord(record);
    }

    @Override
    protected ProducerRecord<byte[], byte[]> toProducerRecord(Record record) {
        ProducerRecord<byte[], byte[]> producerRecord = super.toProducerRecord(record);
        records.add(producerRecord);
        return producerRecord;
    }
}
